@@ -169,10 +169,13 @@ def get_TAs_from_csv(csv_row):
   """
   Input: takes a CSV data row as from a csv.reader.
 
-  Output: returns the list of signed TAs.
+  Output: returns the list of signed TAs. Ensures casefold for TA IDs.
   """
-  return list(filter(lambda x: x.strip(),
-    csv_row[len(SIGNUP_SHEET_HEADER):]))
+  return list(
+    map(lambda x: x.casefold(),
+      filter(lambda x: x.strip(),
+        csv_row[len(SIGNUP_SHEET_HEADER):]))
+    )
 def get_booked_TAs_from_csv(csv_row):
   """
   Input: takes a CSV data row as from a csv.reader.
@@ -191,9 +194,9 @@ def filter_events_by_TA(ta_id, csv_rows):
 
   Output: a list of CSV rows containing only the rows containing ta_id.
   """
-  return list(filter(
-    lambda x: ta_id in get_TAs_from_csv(x),
-    csv_rows))
+  return list(
+    filter(lambda x: ta_id.casefold() in get_TAs_from_csv(x),
+      csv_rows))
 def filter_events_by_title(event_title, csv_rows):
   """
   Input: event_title is the substring to match the event title against;
@@ -330,7 +333,6 @@ def hours_per_TA(csv_rows, add_prep_time=add_prep_time, round_time=round_time):
     booked, _ = get_booked_TAs_from_csv(row)
 
     for assistant in booked:
-      assistant = assistant.casefold()
       if assistant in TA_hours:
         TA_hours[assistant] += time
       else:
